@@ -1,7 +1,9 @@
 #import inspect
-from defichainUtils.utils.utils import int2hex, convert_hex, encodeBech32AddressToHex
+import utils.utils as utils #import int2hex, convert_hex, encodeBech32AddressToHex
 from dataclasses import dataclass, is_dataclass
 
+
+
 DECIMALS = 100000000
 class DfTx():
     def __init__(self):
@@ -17,7 +19,7 @@ class DfTx():
             if i == 0 and p not in [CustomTxType.DepositToVault]:
                 lengthInfo = '4c'
 
-        return OPCodes.OP_RETURN + lengthInfo + int2hex(int(len(h)/2),'little') + h
+        return OPCodes.OP_RETURN + lengthInfo + utils.int2hex(int(len(h)/2),'little') + h
 
     def __handleParam(self,p,isCustomTxType=False):
         if isCustomTxType:
@@ -27,9 +29,9 @@ class DfTx():
         
         
         if p.__class__.__name__ == 'Vault':
-            return convert_hex(p.value,'big','little')
+            return utils.convert_hex(p.value,'big','little')
         elif p.__class__.__name__ == 'Address':
-            return encodeBech32AddressToHex(p.value)
+            return utils.encodeBech32AddressToHex(p.value)
         # elif p.__class__.__name__ == 'Addresses':
         #     h = ''
         #     for address in p.value:
@@ -38,16 +40,16 @@ class DfTx():
         elif p.__class__.__name__ == 'Amounts':
             h = ''
             for amount in p.value:
-                h = h + int2hex(amount[1],'little',4) + int2hex(int(amount[0]*DECIMALS),'little',8)
-            return int2hex(len(p.value),'little') + h
+                h = h + utils.int2hex(amount[1],'little',4) + utils.int2hex(int(amount[0]*DECIMALS),'little',8)
+            return utils.int2hex(len(p.value),'little') + h
         elif p.__class__.__name__ == 'AddressesWithAmount':
             d = p.toDict()
             h = ''
             for address in d:
                 # 01 means, count of addresses (=1)
-                h = h + '01' + encodeBech32AddressToHex(address) + int2hex(len(d[address].keys()),'little')
+                h = h + '01' + utils.encodeBech32AddressToHex(address) + utils.int2hex(len(d[address].keys()),'little')
                 for tokenId in d[address]:
-                    h = h + int2hex(tokenId,'little',4) + int2hex(int(d[address][tokenId]*DECIMALS),'little',8)
+                    h = h + utils.int2hex(tokenId,'little',4) + utils.int2hex(int(d[address][tokenId]*DECIMALS),'little',8)
             return h
         else:
             return ''
