@@ -1,4 +1,4 @@
-import defichainUtils.utils.utils as utils
+import utils.utils as utils
 
 def decodeCustomTx(hex):
     '''
@@ -83,8 +83,8 @@ def decodePoolSwapV2(hex):
         {'bytesCount': 8, 'key': 'fromAmount', 'type': int,'endian':'big'},
         {'key': 'to', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'toTokenId', 'type': int,'endian':None},
-        {'bytesCount': 8, 'key': 'maxPricePredecimal', 'type': int,'endian':'big'},
-        {'bytesCount': 8, 'key': 'maxPriceDecimal', 'type': int,'endian':'big'},
+        {'bytesCount': 8, 'key': 'maxPriceCounter', 'type': int,'endian':'big'},
+        {'bytesCount': 8, 'key': 'maxPriceDenominator', 'type': int,'endian':'big'},
         {'key':'pools', 'type':
             [{'bytesCount': 1, 'type': int,'endian':None}]
         }
@@ -95,7 +95,7 @@ def decodeAddPoolLiquidity(hex):
         {'key':'addresses', 'type': [
             {'key': 'from', 'type': 'address','endian':None},
             {'key': 'amounts', 'type': [
-                {'bytesCount': 1,'key': 'tokenId', 'type': int,'endian':None},
+                {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'big'},
                 {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'big'}
                 ]}
         ]},
